@@ -9,7 +9,7 @@ use File::Spec;
 use File::System;
 use Log::Log4perl;
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 use base 'File::System::Passthrough';
 
@@ -88,12 +88,14 @@ sub lookup_source {
 
 	my $result;
 
-	$log->debug("searching for a source for $path");
+	$log->is_debug &&
+		$log->debug("searching for a source for $path");
 	my $file = $self->lookup($path);
 	if (defined $file && $file->has_content) {
 		$result = $file;
 	} elsif (defined $file && $file->is_container) {
-		$log->debug("searching for directory index $path/index.*");
+		$log->is_debug &&
+			$log->debug("searching for directory index $path/index.*");
 		my @files = $self->glob("$path/index.*");
 		for my $index_file (@files) {
 			if ($file = $self->lookup($index_file) and $file->has_content) {
@@ -105,7 +107,8 @@ sub lookup_source {
 		my $copy = $path;
 		$copy =~ s/\.[\w\.]+$//;
 
-		$log->debug("searching for alternate file $copy.*");
+		$log->is_debug &&
+			$log->debug("searching for alternate file $copy.*");
 
 		my @files = $self->glob("$copy.*");
 		for my $source_file (@files) {
@@ -158,6 +161,25 @@ sub get_property {
 	}
 }
 
+=item $headers = $obj-E<gt>generate_headers(@_)
+
+This method is only valid when C<has_content> returns true. This calls the C<generate_headers> method of the file type returned by the C<filetype> method or returns an empty hash reference.
+
+=cut
+
+sub generate_headers {
+	my $self = shift;
+
+	$self->has_content
+		or croak "Cannot call 'generate_headers' on a file with no content.";
+
+	if (my $filetype = $self->filetype) {
+		return $filetype->generate_headers($self, @_);
+	} else {
+		return {};
+	}
+}
+
 =item $result = $obj-E<gt>generate(@_)
 
 This causes the output of the object to be generated and printed to the currently selected file handle. The result of this generation is also returned.
@@ -245,7 +267,8 @@ sub filetype {
 		warn "Failed to load $plugin: $@" if $@;
 
 		if ($plugin->can('filetype_match') && $plugin->filetype_match($self)) {
-			$log->debug("Matched file $self with filetype $plugin");
+			$log->is_debug &&
+				$log->debug("Matched file $self with filetype $plugin");
 			return $self->{filetype} = $plugin;
 		}
 	}
